stm32-metapac

Crates

git

Versions

stm32u535re

Flavors

Sitfcr

Struct Sitfcr 

#[repr(transparent)]
pub struct Sitfcr(pub u32);
ADF serial interface control register 0.

Tuple Fields

0: u32

Implementations



impl Sitfcr

pub const fn sitfen(&self) -> bool

pub const fn set_sitfen(&mut self, val: bool)

pub const fn scksrc(&self) -> Scksrc

pub const fn set_scksrc(&mut self, val: Scksrc)

pub const fn sitfmod(&self) -> Sitfmod

pub const fn set_sitfmod(&mut self, val: Sitfmod)

pub const fn sth(&self) -> u8

Manchester symbol threshold/SPI threshold. This bitfield is set and cleared by software. It is used for Manchester mode to define the expected symbol threshold levels (seer to Manchester mode for details on computation). In addition this bitfield is used to define the timeout value for the clock absence detection in Normal SPI mode. STH[4:0] values lower than four are invalid.

pub const fn set_sth(&mut self, val: u8)

Manchester symbol threshold/SPI threshold. This bitfield is set and cleared by software. It is used for Manchester mode to define the expected symbol threshold levels (seer to Manchester mode for details on computation). In addition this bitfield is used to define the timeout value for the clock absence detection in Normal SPI mode. STH[4:0] values lower than four are invalid.

pub const fn sitfactive(&self) -> bool

SITFACTIVE.

pub const fn set_sitfactive(&mut self, val: bool)

SITFACTIVE.